==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/BuildStatusOutputToBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class BuildStatusOutputToBuilder extends io.fabric8.openshift.api.model.BuildStatusOutputToFluentImpl<io.fabric8.openshift.api.model.BuildStatusOutputToBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.BuildStatusOutputTo,io.fabric8.openshift.api.model.BuildStatusOutputToBuilder>{
  public BuildStatusOutputToBuilder() {
    this(false);
  }
  public BuildStatusOutputToBuilder(java.lang.Boolean validationEnabled) {
    this(new BuildStatusOutputTo(), validationEnabled);
  }
  public BuildStatusOutputToBuilder(io.fabric8.openshift.api.model.BuildStatusOutputToFluent<?> fluent) {
    this(fluent, false);
  }
  public BuildStatusOutputToBuilder(io.fabric8.openshift.api.model.BuildStatusOutputToFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new BuildStatusOutputTo(), validationEnabled);
  }
  public BuildStatusOutputToBuilder(io.fabric8.openshift.api.model.BuildStatusOutputToFluent<?> fluent,io.fabric8.openshift.api.model.BuildStatusOutputTo instance) {
    this(fluent, instance, false);
  }
  public BuildStatusOutputToBuilder(io.fabric8.openshift.api.model.BuildStatusOutputToFluent<?> fluent,io.fabric8.openshift.api.model.BuildStatusOutputTo instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withImageDigest(instance.getImageDigest()); 
    this.validationEnabled = validationEnabled; 
  }
  public BuildStatusOutputToBuilder(io.fabric8.openshift.api.model.BuildStatusOutputTo instance) {
    this(instance,false);
  }
  public BuildStatusOutputToBuilder(io.fabric8.openshift.api.model.BuildStatusOutputTo instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withImageDigest(instance.getImageDigest()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.BuildStatusOutputToFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.BuildStatusOutputTo build() {
    BuildStatusOutputTo buildable = new BuildStatusOutputTo(fluent.getImageDigest());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BuildStatusOutputToBuilder that = (BuildStatusOutputToBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/BuildStatusOutputToBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class BuildStatusOutputToBuilder extends io.fabric8.openshift.api.model.BuildStatusOutputToFluentImpl<io.fabric8.openshift.api.model.BuildStatusOutputToBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.BuildStatusOutputTo,io.fabric8.openshift.api.model.BuildStatusOutputToBuilder>{
  public BuildStatusOutputToBuilder() {
    this(false);
  }
  public BuildStatusOutputToBuilder(java.lang.Boolean validationEnabled) {
    this(new BuildStatusOutputTo(), validationEnabled);
  }
  public BuildStatusOutputToBuilder(io.fabric8.openshift.api.model.BuildStatusOutputToFluent<?> fluent) {
    this(fluent, false);
  }
  public BuildStatusOutputToBuilder(io.fabric8.openshift.api.model.BuildStatusOutputToFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new BuildStatusOutputTo(), validationEnabled);
  }
  public BuildStatusOutputToBuilder(io.fabric8.openshift.api.model.BuildStatusOutputToFluent<?> fluent,io.fabric8.openshift.api.model.BuildStatusOutputTo instance) {
    this(fluent, instance, false);
  }
  public BuildStatusOutputToBuilder(io.fabric8.openshift.api.model.BuildStatusOutputToFluent<?> fluent,io.fabric8.openshift.api.model.BuildStatusOutputTo instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withImageDigest(instance.getImageDigest()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public BuildStatusOutputToBuilder(io.fabric8.openshift.api.model.BuildStatusOutputTo instance) {
    this(instance,false);
  }
  public BuildStatusOutputToBuilder(io.fabric8.openshift.api.model.BuildStatusOutputTo instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withImageDigest(instance.getImageDigest()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.BuildStatusOutputToFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.BuildStatusOutputTo build() {
    BuildStatusOutputTo buildable = new BuildStatusOutputTo(fluent.getImageDigest());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BuildStatusOutputToBuilder that = (BuildStatusOutputToBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
